splash_smoke library

Classes

BlurredCircle
ConditionalNavigations
A class that facilitates conditional navigation between two pages based on a specified condition.
SplashSmoke
A widget that displays a splash screen with a smoke effect before navigating to the next page or performing conditional navigation.
StartScreen
A StatefulWidget that represents the starting screen of the application.

Enums

TransitionType
An enumeration that defines various types of transitions that can be used for animations or navigation effects.