ConditionalNavigations class
A class that facilitates conditional navigation between two pages based on a specified condition.
The ConditionalNavigations class evaluates a boolean condition and navigates to either
the truePage or the falsePage depending on the result of the condition.
Constructors
Properties
Methods
-
evaluate(
) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited