TransitionType enum
An enumeration that defines various types of transitions that can be used for animations or navigation effects.
The available transition types are:
leftToRight: Transition from left to right.rightToLeft: Transition from right to left.topToBottom: Transition from top to bottom.bottomToTop: Transition from bottom to top.fade: A fade-in or fade-out transition.scale: A scaling transition, where the element grows or shrinks.rotate: A rotational transition.
Values
- leftToRight → const TransitionType
- rightToLeft → const TransitionType
- topToBottom → const TransitionType
- bottomToTop → const TransitionType
- fade → const TransitionType
- scale → const TransitionType
- rotate → const TransitionType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TransitionType> - A constant List of the values in this enum, in order of their declaration.